==> freecad_0.16.6712+dfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Web/Gui/Resources/translations/Web.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CmdWebBrowserBack</name>
    <message>
        <location filename="../../Command.cpp" line="75"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="76"/>
        <source>Previous page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="77"/>
        <source>Go back to the previous page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserNext</name>
    <message>
        <location filename="../../Command.cpp" line="103"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="104"/>
        <source>Next page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="105"/>
        <source>Go to the next page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserRefresh</name>
    <message>
        <location filename="../../Command.cpp" line="131"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="132"/>
        <location filename="../../Command.cpp" line="133"/>
        <source>Refresh web page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserStop</name>
    <message>
        <location filename="../../Command.cpp" line="158"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="159"/>
        <source>Stop loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="160"/>
        <source>Stop the current loading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
        <location filename="../../Command.cpp" line="187"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="188"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="189"/>
        <source>Zoom into the page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
        <location filename="../../Command.cpp" line="215"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="216"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="217"/>
        <source>Zoom out of the page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebOpenWebsite</name>
    <message>
        <location filename="../../Command.cpp" line="50"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="51"/>
        <source>Open website...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="52"/>
        <source>Opens a website in FreeCAD</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../AppWebGui.cpp" line="78"/>
        <location filename="../../BrowserView.cpp" line="348"/>
        <source>Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="244"/>
        <source>File does not exist!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebGui::BrowserView</name>
    <message>
        <location filename="../../BrowserView.cpp" line="239"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="319"/>
        <source>Loading %1...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebGui::WebView</name>
    <message>
        <location filename="../../BrowserView.cpp" line="121"/>
        <source>Open in External Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="125"/>
        <source>Open in new window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../Workbench.cpp" line="46"/>
        <source>Navigation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Web/Gui/Resources/translations/Web.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CmdWebBrowserBack</name>
    <message>
        <location filename="../../Command.cpp" line="76"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="77"/>
        <source>Previous page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="78"/>
        <source>Go back to the previous page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserNext</name>
    <message>
        <location filename="../../Command.cpp" line="105"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="106"/>
        <source>Next page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="107"/>
        <source>Go to the next page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserRefresh</name>
    <message>
        <location filename="../../Command.cpp" line="134"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="135"/>
        <location filename="../../Command.cpp" line="136"/>
        <source>Refresh web page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserStop</name>
    <message>
        <location filename="../../Command.cpp" line="162"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="163"/>
        <location filename="../../Command.cpp" line="164"/>
        <source>Stop loading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
        <location filename="../../Command.cpp" line="192"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="193"/>
        <location filename="../../Command.cpp" line="194"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
        <location filename="../../Command.cpp" line="221"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="222"/>
        <location filename="../../Command.cpp" line="223"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdWebOpenWebsite</name>
    <message>
        <location filename="../../Command.cpp" line="50"/>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="51"/>
        <source>Open website...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="52"/>
        <source>Opens a website in FreeCAD</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../AppWebGui.cpp" line="80"/>
        <location filename="../../BrowserView.cpp" line="441"/>
        <source>Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="338"/>
        <source>File does not exist!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebGui::BrowserView</name>
    <message>
        <location filename="../../BrowserView.cpp" line="329"/>
        <location filename="../../BrowserView.cpp" line="334"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="334"/>
        <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="412"/>
        <source>Loading %1...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebGui::WebView</name>
    <message>
        <location filename="../../BrowserView.cpp" line="185"/>
        <source>Open in External Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../BrowserView.cpp" line="189"/>
        <source>Open in new window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../Workbench.cpp" line="46"/>
        <source>Navigation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
